# `wap new-project`

`wap new-project [OPTIONS]`

Create a new project in the current directory by answering some questions.

!!! note

    If you just want to create a new configuration file, use [`wap new-config`](./new-config.md)

## Options

### `--help`

`--help`

Show the built-in help text and exit.
